@@ -24,5 +24,5 @@ is_grouped_spatvector <- function(x) {
     return(TRUE)
   }
 
-  return(FALSE)
+  FALSE
 }
