@@ -49,29 +49,30 @@
 #'
 #'
 #' f <- system.file("extdata/cyl_tile.tif", package = "tidyterra")
-#' spatrast <- rast(f) %>% mutate(aa = 1, bb = 2, cc = 3)
+#' spatrast <- rast(f) |> mutate(aa = 1, bb = 2, cc = 3)
 #'
 #' names(spatrast)
 #'
 #'
-#' spatrast %>%
-#'   relocate(bb, .before = cyl_tile_3) %>%
+#' spatrast |>
+#'   relocate(bb, .before = cyl_tile_3) |>
 #'   relocate(cyl_tile_1, .after = last_col())
 #'
 relocate.SpatRaster <- function(.data, ..., .before = NULL, .after = NULL) {
   # With template
   df <- .data[1]
 
-  values_relocated <- dplyr::relocate(df, ...,
+  values_relocated <- dplyr::relocate(
+    df,
+    ...,
     .before = {{ .before }},
     .after = {{ .after }}
   )
 
-
   finalrast <- .data
   finalrast <- terra::subset(finalrast, names(values_relocated))
 
-  return(finalrast)
+  finalrast
 }
 
 
@@ -82,7 +83,9 @@ relocate.SpatVector <- function(.data, ..., .before = NULL, .after = NULL) {
   # With template
   df <- as_tibble(.data[1, ])
 
-  values_relocated <- dplyr::relocate(df, ...,
+  values_relocated <- dplyr::relocate(
+    df,
+    ...,
     .before = {{ .before }},
     .after = {{ .after }}
   )
@@ -90,7 +93,7 @@ relocate.SpatVector <- function(.data, ..., .before = NULL, .after = NULL) {
   vend <- .data[, names(values_relocated)]
   vend <- group_prepare_spat(vend, values_relocated)
 
-  return(vend)
+  vend
 }
 
 #' @export
