@@ -49,16 +49,16 @@
 #'
 #' library(terra)
 #' f <- system.file("extdata/cyl_tile.tif", package = "tidyterra")
-#' spatrast <- rast(f) %>% mutate(aa = 1, bb = 2, cc = 3)
+#' spatrast <- rast(f) |> mutate(aa = 1, bb = 2, cc = 3)
 #'
 #' spatrast
 #'
-#' spatrast %>% rename(
+#' spatrast |> rename(
 #'   this_first = cyl_tile_1,
 #'   this_second = cyl_tile_2
 #' )
 #'
-#' spatrast %>% rename_with(
+#' spatrast |> rename_with(
 #'   toupper,
 #'   .cols = starts_with("c")
 #' )
@@ -70,7 +70,7 @@ rename.SpatRaster <- function(.data, ...) {
   final_rast <- .data
   names(final_rast) <- names(df_rename)
 
-  return(final_rast)
+  final_rast
 }
 
 #' @rdname rename.Spat
@@ -93,7 +93,7 @@ rename_with.SpatRaster <- function(.data, .fn, .cols = everything(), ...) {
   final_rast <- .data
   names(final_rast) <- names(df_rename)
 
-  return(final_rast)
+  final_rast
 }
 
 #' @rdname rename.Spat
