@@ -96,65 +96,68 @@
 #' r <- rast(f)
 #'
 #' # Slice first 100 cells
-#' r %>%
-#'   slice(1:100) %>%
+#' r |>
+#'   slice(1:100) |>
 #'   plot()
 #'
 #' # Rows
-#' r %>%
-#'   slice_rows(1:30) %>%
+#' r |>
+#'   slice_rows(1:30) |>
 #'   plot()
 #'
 #' # Cols
-#' r %>%
-#'   slice_cols(-(20:50)) %>%
+#' r |>
+#'   slice_cols(-(20:50)) |>
 #'   plot()
 #'
 #' # Spatial sample
-#' r %>%
-#'   slice_sample(prop = 0.2) %>%
+#' r |>
+#'   slice_sample(prop = 0.2) |>
 #'   plot()
 #'
 #'
 #' # Slice regions
-#' r %>%
+#' r |>
 #'   slice_colrows(
 #'     cols = c(20:40, 60:80),
 #'     rows = -c(1:20, 30:50)
-#'   ) %>%
+#'   ) |>
 #'   plot()
 #'
 #' # Group wise operation with SpatVectors--------------------------------------
 #' v <- terra::vect(system.file("ex/lux.shp", package = "terra"))
 #'
 #' \donttest{
-#' glimpse(v) %>% autoplot(aes(fill = NAME_1))
+#' glimpse(v) |> autoplot(aes(fill = NAME_1))
 #'
-#' gv <- v %>% group_by(NAME_1)
+#' gv <- v |> group_by(NAME_1)
 #' # All slice helpers operate per group, silently truncating to the group size
-#' gv %>%
-#'   slice_head(n = 1) %>%
-#'   glimpse() %>%
+#' gv |>
+#'   slice_head(n = 1) |>
+#'   glimpse() |>
 #'   autoplot(aes(fill = NAME_1))
-#' gv %>%
-#'   slice_tail(n = 1) %>%
-#'   glimpse() %>%
+#' gv |>
+#'   slice_tail(n = 1) |>
+#'   glimpse() |>
 #'   autoplot(aes(fill = NAME_1))
-#' gv %>%
-#'   slice_min(AREA, n = 1) %>%
-#'   glimpse() %>%
+#' gv |>
+#'   slice_min(AREA, n = 1) |>
+#'   glimpse() |>
 #'   autoplot(aes(fill = NAME_1))
-#' gv %>%
-#'   slice_max(AREA, n = 1) %>%
-#'   glimpse() %>%
+#' gv |>
+#'   slice_max(AREA, n = 1) |>
+#'   glimpse() |>
 #'   autoplot(aes(fill = NAME_1))
 #' }
-slice.SpatRaster <- function(.data, ..., .preserve = FALSE,
-                             .keep_extent = FALSE) {
+slice.SpatRaster <- function(
+  .data,
+  ...,
+  .preserve = FALSE,
+  .keep_extent = FALSE
+) {
   # Create skeleton
   skeleton <- as_coordinates(.data)
 
-
   sliced <- dplyr::slice(skeleton, ...)
 
   keepcells <- sliced$cellindex
@@ -173,14 +176,12 @@ slice.SpatRaster <- function(.data, ..., .preserve = FALSE,
     return(newrast)
   }
 
-
   # Crop to selected range
   range <- range(keepcells)
   keepindex <- seq(range[1], range[2], by = 1)
   newrast <- newrast[keepindex, drop = FALSE]
 
-
-  return(newrast)
+  newrast
 }
 #' @export
 #' @rdname slice.Spat
@@ -209,7 +210,6 @@ slice_head.SpatRaster <- function(.data, ..., n, prop, .keep_extent = FALSE) {
 
   keepcells <- sliced$cellindex
 
-
   # Make NA cells
 
   # To NA
@@ -225,7 +225,7 @@ slice_head.SpatRaster <- function(.data, ..., n, prop, .keep_extent = FALSE) {
 
   newrast <- newrast[keepcells, drop = FALSE]
 
-  return(newrast)
+  newrast
 }
 
 #' @export
@@ -272,7 +272,7 @@ slice_tail.SpatRaster <- function(.data, ..., n, prop, .keep_extent = FALSE) {
 
   newrast <- newrast[keepcells, drop = FALSE]
 
-  return(newrast)
+  newrast
 }
 
 #' @export
@@ -296,9 +296,16 @@ slice_tail.SpatVector <- function(.data, ..., n, prop) {
 #' @export
 #' @rdname slice.Spat
 #' @importFrom dplyr slice_min
-slice_min.SpatRaster <- function(.data, order_by, ..., n, prop,
-                                 with_ties = TRUE, .keep_extent = FALSE,
-                                 na.rm = TRUE) {
+slice_min.SpatRaster <- function(
+  .data,
+  order_by,
+  ...,
+  n,
+  prop,
+  with_ties = TRUE,
+  .keep_extent = FALSE,
+  na.rm = TRUE
+) {
   # Create skeleton
   skeleton <- as_coordinates(.data)
   values <- as_tibble(.data, na.rm = FALSE, xy = FALSE)
@@ -310,11 +317,16 @@ slice_min.SpatRaster <- function(.data, order_by, ..., n, prop,
   skeleton <- dplyr::bind_cols(skeleton, values)
 
   # Remove NAs
-  if (na.rm) skeleton <- tidyr::drop_na(skeleton)
+  if (na.rm) {
+    skeleton <- tidyr::drop_na(skeleton)
+  }
 
-  sliced <- dplyr::slice_min(skeleton,
+  sliced <- dplyr::slice_min(
+    skeleton,
     order_by = {{ order_by }},
-    ..., n = n, prop = prop,
+    ...,
+    n = n,
+    prop = prop,
     with_ties = with_ties
   )
 
@@ -328,7 +340,6 @@ slice_min.SpatRaster <- function(.data, order_by, ..., n, prop,
   newrast <- .data
   newrast[tonas] <- NA
 
-
   # With keep_extent we just replaced the cells with NAs
   if (.keep_extent) {
     return(newrast)
@@ -339,21 +350,34 @@ slice_min.SpatRaster <- function(.data, order_by, ..., n, prop,
   keepindex <- seq(range[1], range[2], by = 1)
   newrast <- newrast[keepindex, drop = FALSE]
 
-  return(newrast)
+  newrast
 }
 
 #' @export
 #' @rdname slice.Spat
-slice_min.SpatVector <- function(.data, order_by, ..., n, prop,
-                                 with_ties = TRUE, na_rm = FALSE) {
+slice_min.SpatVector <- function(
+  .data,
+  order_by,
+  ...,
+  n,
+  prop,
+  with_ties = TRUE,
+  na_rm = FALSE
+) {
   # Use own method
   tbl <- as_tibble(.data)
   ind <- make_safe_index("tterra_index", tbl)
   tbl[[ind]] <- seq_len(nrow(tbl))
 
-  sliced <- dplyr::slice_min(tbl, ...,
-    order_by = {{ order_by }}, ..., n = n,
-    prop = prop, with_ties = with_ties, na_rm = na_rm
+  sliced <- dplyr::slice_min(
+    tbl,
+    ...,
+    order_by = {{ order_by }},
+    ...,
+    n = n,
+    prop = prop,
+    with_ties = with_ties,
+    na_rm = na_rm
   )
 
   # Regenerate
@@ -367,9 +391,16 @@ slice_min.SpatVector <- function(.data, order_by, ..., n, prop,
 #' @export
 #' @rdname slice.Spat
 #' @importFrom dplyr slice_max
-slice_max.SpatRaster <- function(.data, order_by, ..., n, prop,
-                                 with_ties = TRUE, .keep_extent = FALSE,
-                                 na.rm = TRUE) {
+slice_max.SpatRaster <- function(
+  .data,
+  order_by,
+  ...,
+  n,
+  prop,
+  with_ties = TRUE,
+  .keep_extent = FALSE,
+  na.rm = TRUE
+) {
   # Create skeleton
   skeleton <- as_coordinates(.data)
   values <- as_tibble(.data, na.rm = FALSE, xy = FALSE)
@@ -381,11 +412,16 @@ slice_max.SpatRaster <- function(.data, order_by, ..., n, prop,
   skeleton <- dplyr::bind_cols(skeleton, values)
 
   # Remove NAs
-  if (na.rm) skeleton <- tidyr::drop_na(skeleton)
+  if (na.rm) {
+    skeleton <- tidyr::drop_na(skeleton)
+  }
 
-  sliced <- dplyr::slice_max(skeleton,
+  sliced <- dplyr::slice_max(
+    skeleton,
     order_by = {{ order_by }},
-    ..., n = n, prop = prop,
+    ...,
+    n = n,
+    prop = prop,
     with_ties = with_ties
   )
 
@@ -399,7 +435,6 @@ slice_max.SpatRaster <- function(.data, order_by, ..., n, prop,
   newrast <- .data
   newrast[tonas] <- NA
 
-
   # With keep_extent we just replaced the cells with NAs
   if (.keep_extent) {
     return(newrast)
@@ -410,21 +445,34 @@ slice_max.SpatRaster <- function(.data, order_by, ..., n, prop,
   keepindex <- seq(range[1], range[2], by = 1)
   newrast <- newrast[keepindex, drop = FALSE]
 
-  return(newrast)
+  newrast
 }
 
 #' @export
 #' @rdname slice.Spat
-slice_max.SpatVector <- function(.data, order_by, ..., n, prop,
-                                 with_ties = TRUE, na_rm = FALSE) {
+slice_max.SpatVector <- function(
+  .data,
+  order_by,
+  ...,
+  n,
+  prop,
+  with_ties = TRUE,
+  na_rm = FALSE
+) {
   # Use own method
   tbl <- as_tibble(.data)
   ind <- make_safe_index("tterra_index", tbl)
   tbl[[ind]] <- seq_len(nrow(tbl))
 
-  sliced <- dplyr::slice_max(tbl, ...,
-    order_by = {{ order_by }}, ..., n = n,
-    prop = prop, with_ties = with_ties, na_rm = na_rm
+  sliced <- dplyr::slice_max(
+    tbl,
+    ...,
+    order_by = {{ order_by }},
+    ...,
+    n = n,
+    prop = prop,
+    with_ties = with_ties,
+    na_rm = na_rm
   )
 
   # Regenerate
@@ -438,9 +486,15 @@ slice_max.SpatVector <- function(.data, order_by, ..., n, prop,
 #' @export
 #' @rdname slice.Spat
 #' @importFrom dplyr slice_sample
-slice_sample.SpatRaster <- function(.data, ..., n, prop,
-                                    weight_by = NULL, replace = FALSE,
-                                    .keep_extent = FALSE) {
+slice_sample.SpatRaster <- function(
+  .data,
+  ...,
+  n,
+  prop,
+  weight_by = NULL,
+  replace = FALSE,
+  .keep_extent = FALSE
+) {
   # Create skeleton
   skeleton <- as_coordinates(.data)
   values <- as_tibble(.data, na.rm = FALSE, xy = FALSE)
@@ -451,9 +505,12 @@ slice_sample.SpatRaster <- function(.data, ..., n, prop,
   # Add values
   skeleton <- dplyr::bind_cols(skeleton, values)
 
-  sliced <- dplyr::slice_sample(skeleton, ...,
+  sliced <- dplyr::slice_sample(
+    skeleton,
+    ...,
     n = n,
-    prop = prop, weight_by = weight_by,
+    prop = prop,
+    weight_by = weight_by,
     replace = replace
   )
 
@@ -477,13 +534,19 @@ slice_sample.SpatRaster <- function(.data, ..., n, prop,
   keepindex <- seq(range[1], range[2], by = 1)
   newrast <- newrast[keepindex, drop = FALSE]
 
-  return(newrast)
+  newrast
 }
 
 #' @export
 #' @rdname slice.Spat
-slice_sample.SpatVector <- function(.data, ..., n, prop,
-                                    weight_by = NULL, replace = FALSE) {
+slice_sample.SpatVector <- function(
+  .data,
+  ...,
+  n,
+  prop,
+  weight_by = NULL,
+  replace = FALSE
+) {
   # Use own method
   tbl <- as_tibble(.data)
   ind <- make_safe_index("tterra_index", tbl)
@@ -517,10 +580,7 @@ slice_rows.SpatRaster <- function(.data, ..., .keep_extent = FALSE) {
   slice_dim <- dplyr::slice(index, ...)
 
   # Get cells to make NA
-  sliced <- dplyr::inner_join(skeleton,
-    slice_dim,
-    by = "rowindex"
-  )
+  sliced <- dplyr::inner_join(skeleton, slice_dim, by = "rowindex")
 
   keepcells <- sliced$cellindex
 
@@ -542,7 +602,7 @@ slice_rows.SpatRaster <- function(.data, ..., .keep_extent = FALSE) {
   keepindex <- seq(range[1], range[2], by = 1)
   newrast <- newrast[keepindex, , drop = FALSE]
 
-  return(newrast)
+  newrast
 }
 
 #' @export
@@ -564,10 +624,7 @@ slice_cols.SpatRaster <- function(.data, ..., .keep_extent = FALSE) {
   slice_dim <- dplyr::slice(index, ...)
 
   # Get cells to make NA
-  sliced <- dplyr::inner_join(skeleton,
-    slice_dim,
-    by = "colindex"
-  )
+  sliced <- dplyr::inner_join(skeleton, slice_dim, by = "colindex")
 
   keepcells <- sliced$cellindex
 
@@ -589,7 +646,7 @@ slice_cols.SpatRaster <- function(.data, ..., .keep_extent = FALSE) {
   keepindex <- seq(range[1], range[2], by = 1)
   newrast <- newrast[, keepindex, drop = FALSE]
 
-  return(newrast)
+  newrast
 }
 
 #' @export
@@ -600,9 +657,14 @@ slice_colrows <- function(.data, ...) {
 
 #' @export
 #' @rdname slice.Spat
-slice_colrows.SpatRaster <- function(.data, ..., cols, rows,
-                                     .keep_extent = FALSE,
-                                     inverse = FALSE) {
+slice_colrows.SpatRaster <- function(
+  .data,
+  ...,
+  cols,
+  rows,
+  .keep_extent = FALSE,
+  inverse = FALSE
+) {
   # Create skeleton
   skeleton <- as_coordinates(.data)
 
@@ -617,7 +679,6 @@ slice_colrows.SpatRaster <- function(.data, ..., cols, rows,
 
   slice_cols <- dplyr::slice(col_index, cols)
 
-
   # Rows
   row_index <- skeleton["rowindex"]
   row_index$rowindex <- sort(row_index$rowindex)
@@ -626,16 +687,9 @@ slice_colrows.SpatRaster <- function(.data, ..., cols, rows,
   slice_rows <- dplyr::slice(row_index, rows)
 
   # Get cells to make NA
-  sliced <- dplyr::inner_join(skeleton,
-    slice_cols,
-    by = "colindex"
-  )
-
-  sliced <- dplyr::inner_join(sliced,
-    slice_rows,
-    by = "rowindex"
-  )
+  sliced <- dplyr::inner_join(skeleton, slice_cols, by = "colindex")
 
+  sliced <- dplyr::inner_join(sliced, slice_rows, by = "rowindex")
 
   keepcells <- sliced$cellindex
 
@@ -662,8 +716,7 @@ slice_colrows.SpatRaster <- function(.data, ..., cols, rows,
 
   newrast <- newrast[keepindex_row, keepindex_col, drop = FALSE]
 
-
-  return(newrast)
+  newrast
 }
 
 #' @export
