@@ -3,19 +3,22 @@ across_all_of <- function(vars) {
 }
 
 as_spat_internal <- function(x) {
-  if (any(
-    inherits(x, "SpatRaster"),
-    isTRUE(attr(x, "source") == "SpatRaster")
-  )) {
+  if (
+    any(
+      inherits(x, "SpatRaster"),
+      isTRUE(attr(x, "source") == "SpatRaster")
+    )
+  ) {
     return(as_spatrast_attr(x))
-  } else if (any(
-    inherits(x, "SpatVector"),
-    isTRUE(attr(x, "source") == "SpatVector")
-  )) {
+  } else if (
+    any(
+      inherits(x, "SpatVector"),
+      isTRUE(attr(x, "source") == "SpatVector")
+    )
+  ) {
     return(as_spatvect_attr(x))
   }
 
-
   cli::cli_abort(paste(
     "Can't convert {.arg x} back to a {.cls Spat*} object.",
     "Something went wrong"
@@ -55,5 +58,5 @@ make_safe_index <- function(x, y) {
     is_safe <- !(x %in% nams)
   }
 
-  return(x)
+  x
 }
