@@ -4,7 +4,7 @@ test_that("SpatRaster mutate", {
   f <- system.file("extdata/cyl_temp.tif", package = "tidyterra")
   spatrast <- terra::rast(f)
 
-  mod <- spatrast %>%
+  mod <- spatrast |>
     mutate(exp_lyr1 = exp(tavg_04 / 10))
 
   expect_true(compare_spatrasters(spatrast, mod))
@@ -22,33 +22,41 @@ test_that("SpatRaster mutate and check names", {
   spatrast <- init
   names(spatrast) <- c("a", "a", "b")
 
-
   expect_snapshot(fixed_names <- dplyr::mutate(spatrast, b2 = a + 100))
 
-  all_eq <- all(names(fixed_names) == make.names(c(
-    names(spatrast),
-    "b2"
-  ), unique = TRUE))
+  all_eq <- all(
+    names(fixed_names) ==
+      make.names(
+        c(
+          names(spatrast),
+          "b2"
+        ),
+        unique = TRUE
+      )
+  )
 
   expect_true(all_eq)
 
   expect_true(compare_spatrasters(init, fixed_names))
 
-
   # Same with layer names as x,y
   names(spatrast) <- c("x", "x", "y")
   expect_snapshot(
     fixed_names2 <- dplyr::mutate(spatrast, b2 = x.1 + x.2 + y.1)
   )
 
-  all_eq <- all(names(fixed_names2) == make.names(
-    c(
-      "x", "y",
-      names(spatrast),
-      "b2"
-    ),
-    unique = TRUE
-  )[-c(1, 2)])
+  all_eq <- all(
+    names(fixed_names2) ==
+      make.names(
+        c(
+          "x",
+          "y",
+          names(spatrast),
+          "b2"
+        ),
+        unique = TRUE
+      )[-c(1, 2)]
+  )
 
   expect_true(all_eq)
 
