@@ -3,15 +3,15 @@ test_that("SpatRaster", {
   f <- system.file("extdata/cyl_temp.tif", package = "tidyterra")
   spatrast <- terra::rast(f)
 
-  mod <- spatrast %>%
-    mutate(exp_lyr1 = exp(tavg_04 / 10)) %>%
+  mod <- spatrast |>
+    mutate(exp_lyr1 = exp(tavg_04 / 10)) |>
     relocate(exp_lyr1, .before = 1)
 
   expect_true(all(names(mod) == c("exp_lyr1", names(spatrast))))
 
   expect_true(compare_spatrasters(spatrast, mod))
 
-  mod2 <- mod %>% relocate(tavg_05, .after = dplyr::last_col())
+  mod2 <- mod |> relocate(tavg_05, .after = dplyr::last_col())
 
   expect_true(compare_spatrasters(spatrast, mod2))
 
@@ -29,16 +29,15 @@ test_that("SpatVector", {
   f <- system.file("extdata/cyl.gpkg", package = "tidyterra")
   v <- terra::vect(f)
 
-  mod <- v %>%
-    mutate(exp_attr = "a") %>%
+  mod <- v |>
+    mutate(exp_attr = "a") |>
     relocate(exp_attr, .before = 1)
 
   expect_s4_class(mod, "SpatVector")
 
   expect_true(all(names(mod) == c("exp_attr", names(v))))
 
-
-  mod2 <- mod %>% relocate(cpro, .after = dplyr::last_col())
+  mod2 <- mod |> relocate(cpro, .after = dplyr::last_col())
 
   expect_s4_class(mod2, "SpatVector")
 
