@@ -6,15 +6,11 @@ test_that("Slice", {
   terra::values(r) <- seq_len(terra::ncell(r))
   names(r) <- "cell_index"
 
-
   # No keep extent
   sliced <- slice(r, 3:134)
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
-
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
   expect_true(all(df$cell_index == 3:134))
@@ -27,29 +23,23 @@ test_that("Slice", {
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
   expect_true(all(df$cell_index == 237:289))
 
-
   # Negative index
   sliced <- slice(r, -seq(1, 250))
 
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
 
   expect_false(any(df$cell_index %in% 1:250))
 
-
   # Mixed rows: No keep
   sliced <- slice(r, c(1:80, 90:131))
 
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
 
@@ -75,22 +65,15 @@ test_that("Slice head", {
   terra::values(r) <- seq_len(terra::ncell(r))
   names(r) <- "cell_index"
 
-
   # No keep extent
   sliced <- slice_head(r)
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
-
-
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
   expect_true(all(df$cell_index == 1))
 
-
-
   # Keep extent
   sliced <- slice_head(r, n = 3, .keep_extent = TRUE)
   expect_s4_class(sliced, "SpatRaster")
@@ -107,9 +90,7 @@ test_that("Slice head", {
 
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
 
@@ -124,7 +105,6 @@ test_that("Slice head", {
 
   expect_silent(compare_spatrasters(r, sliced))
 
-
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
   expect_true(all(df$cell_index == seq_len(aprox)))
 })
@@ -139,22 +119,15 @@ test_that("Slice tail", {
   terra::values(r) <- totcell
   names(r) <- "cell_index"
 
-
   # No keep extent
   sliced <- slice_tail(r)
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
-
-
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
   expect_true(all(df$cell_index == rev(totcell)[1]))
 
-
-
   # Keep extent
   sliced <- slice_tail(r, n = 3, .keep_extent = TRUE)
   expect_s4_class(sliced, "SpatRaster")
@@ -171,9 +144,7 @@ test_that("Slice tail", {
 
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
 
@@ -190,7 +161,6 @@ test_that("Slice tail", {
 
   expect_silent(compare_spatrasters(r, sliced))
 
-
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
 
   vect_comp <- sort(rev(totcell)[seq_len(aprox)])
@@ -221,22 +191,13 @@ test_that("Slice min", {
   sliced <- slice_min(r, order_by = cell_index, n = 3)
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
-
-
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
   expect_true(all(df$cell_index == 1:3))
 
-
-
   # Keep extent
-  sliced <- slice_min(r, log,
-    n = 20, .keep_extent = TRUE,
-    with_ties = FALSE
-  )
+  sliced <- slice_min(r, log, n = 20, .keep_extent = TRUE, with_ties = FALSE)
 
   expect_s4_class(sliced, "SpatRaster")
   expect_silent(compare_spatrasters(r, sliced))
@@ -255,9 +216,7 @@ test_that("Slice min", {
 
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
 
@@ -272,7 +231,6 @@ test_that("Slice min", {
 
   expect_silent(compare_spatrasters(r, sliced))
 
-
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
 
   vect_comp <- sort(rev(totcell)[seq_len(aprox)])
@@ -282,9 +240,8 @@ test_that("Slice min", {
   # Remove NAs option
   r3 <- transmute(r, log2 = ifelse(log > 4, log, NA))
 
-
-  df1 <- as_tibble(slice_min(r3, order_by = log2, prop = .5))
-  df2 <- as_tibble(slice_min(r3, order_by = log2, prop = .5, na.rm = FALSE))
+  df1 <- as_tibble(slice_min(r3, order_by = log2, prop = 0.5))
+  df2 <- as_tibble(slice_min(r3, order_by = log2, prop = 0.5, na.rm = FALSE))
 
   expect_false(nrow(df1) == nrow(df2))
 })
@@ -312,25 +269,15 @@ test_that("Slice max", {
   sliced <- slice_max(r, order_by = cell_index, n = 3)
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
-
-
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
   vect_comp <- sort(rev(totcell)[seq_len(3)])
 
-
   expect_true(all(df$cell_index == vect_comp))
 
-
-
   # Keep extent
-  sliced <- slice_max(r, log,
-    n = 20, .keep_extent = TRUE,
-    with_ties = FALSE
-  )
+  sliced <- slice_max(r, log, n = 20, .keep_extent = TRUE, with_ties = FALSE)
 
   expect_s4_class(sliced, "SpatRaster")
   expect_silent(compare_spatrasters(r, sliced))
@@ -347,15 +294,12 @@ test_that("Slice max", {
 
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
 
   vect_comp <- sort(rev(totcell)[seq_len(aprox)])
 
-
   expect_true(all(df$cell_index == vect_comp))
 
   # With props: Extent
@@ -367,7 +311,6 @@ test_that("Slice max", {
 
   expect_silent(compare_spatrasters(r, sliced))
 
-
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
 
   expect_true(all(df$cell_index == seq_len(aprox)))
@@ -375,9 +318,8 @@ test_that("Slice max", {
   # Remove NAs option
   r3 <- transmute(r, log2 = ifelse(log > 4, log, NA))
 
-
-  df1 <- as_tibble(slice_max(r3, order_by = log2, prop = .5))
-  df2 <- as_tibble(slice_max(r3, order_by = log2, prop = .5, na.rm = FALSE))
+  df1 <- as_tibble(slice_max(r3, order_by = log2, prop = 0.5))
+  df2 <- as_tibble(slice_max(r3, order_by = log2, prop = 0.5, na.rm = FALSE))
 
   expect_false(nrow(df1) == nrow(df2))
 })
@@ -400,34 +342,28 @@ test_that("Slice sample", {
     terra::as.data.frame(slice(r_test, rep(1, 4)))
   )
 
-
   # W replacement
   r_3 <- r[c(1, 3), drop = FALSE]
   sliced <- slice_sample(r_3, n = 20, replace = TRUE)
 
   expect_s4_class(sliced, "SpatRaster")
 
-
   expect_true(terra::ncell(sliced) == terra::ncell(r_3))
 
   # W/0 replacement, no keep extent
   sliced <- slice_sample(r, n = 1, replace = FALSE)
   expect_s4_class(sliced, "SpatRaster")
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
 
   expect_true(nrow(df) == 1)
 
-
   expect_equal(
     unique(df$cell_index),
     df$cell_index
   )
 
-
   # W/0 replacement, keep extent
   sliced <- slice_sample(r, n = 1, replace = FALSE, .keep_extent = TRUE)
   expect_s4_class(sliced, "SpatRaster")
@@ -437,7 +373,6 @@ test_that("Slice sample", {
 
   expect_true(nrow(df) == 1)
 
-
   expect_equal(
     unique(df$cell_index),
     df$cell_index
@@ -466,10 +401,7 @@ test_that("Slice Rows", {
   sliced <- slice_rows(r, 1:5)
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
-
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
   expect_true(all(sort(unique(df$rowindex)) == 1:5))
@@ -489,9 +421,7 @@ test_that("Slice Rows", {
 
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
 
@@ -503,9 +433,7 @@ test_that("Slice Rows", {
 
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
 
@@ -545,10 +473,7 @@ test_that("Slice Cols", {
   sliced <- slice_cols(r, 1:5)
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
-
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
   expect_true(all(sort(unique(df$colindex)) == 1:5))
@@ -568,9 +493,7 @@ test_that("Slice Cols", {
 
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
 
@@ -582,9 +505,7 @@ test_that("Slice Cols", {
 
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
 
@@ -611,7 +532,6 @@ test_that("Slice RowCols", {
   terra::values(r) <- seq_len(terra::ncell(r))
   names(r) <- "cell_index"
 
-
   # Add nrow, ncol
   sk <- as_coordinates(r)
   r2 <- terra::rast(r)
@@ -628,10 +548,7 @@ test_that("Slice RowCols", {
   sliced <- slice_colrows(r, cols = cls, rows = rws)
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
-
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
 
@@ -651,7 +568,6 @@ test_that("Slice RowCols", {
   expect_true(all(sort(unique(df$colindex)) == cls))
   expect_true(all(sort(unique(df$rowindex)) == rws))
 
-
   # Negative index
   rws <- -seq(10, 20)
   cls <- -seq(15, 20)
@@ -661,9 +577,7 @@ test_that("Slice RowCols", {
 
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
 
@@ -677,16 +591,13 @@ test_that("Slice RowCols", {
   sliced <- slice_colrows(r, cols = cls, rows = rws)
   expect_s4_class(sliced, "SpatRaster")
 
-
   expect_s4_class(sliced, "SpatRaster")
 
-  expect_message(compare_spatrasters(r, sliced),
-    regexp = "extent"
-  )
+  expect_message(compare_spatrasters(r, sliced), regexp = "extent")
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
 
-  expect_true(all(!sort(unique(df$colindex)) %in% -cls))
+  expect_true(!any(sort(unique(df$colindex)) %in% -cls))
   expect_true(all(sort(unique(df$rowindex)) == rws))
 
   # Mixed index: Keeps
@@ -701,6 +612,6 @@ test_that("Slice RowCols", {
 
   df <- terra::as.data.frame(sliced, na.rm = TRUE)
 
-  expect_true(all(!sort(unique(df$colindex)) %in% -cls))
+  expect_true(!any(sort(unique(df$colindex)) %in% -cls))
   expect_true(all(sort(unique(df$rowindex)) == rws))
 })
